{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#InterProScan-v5.cwl",
            "baseCommand": [],
            "inputs": [
                {
                    "format": "http://edamontology.org/format_1929",
                    "id": "#InterProScan-v5.cwl/i5/inputFile",
                    "type": "File",
                    "inputBinding": {
                        "position": 8,
                        "prefix": "--input"
                    },
                    "label": "Input file path",
                    "doc": "Optional, path to fasta file that should be loaded on Master startup. Alternatively, in CONVERT mode, the InterProScan 5 XML file to convert."
                },
                {
                    "id": "#InterProScan-v5.cwl/i5/applications",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "#InterProScan-apps.yaml/apps"
                        }
                    ],
                    "inputBinding": {
                        "position": 9,
                        "itemSeparator": ",",
                        "prefix": "--applications"
                    },
                    "label": "Analysis",
                    "doc": "Optional, comma separated list of analyses. If this option is not set, ALL analyses will be run."
                },
                {
                    "id": "#InterProScan-v5.cwl/i5/outputFormat",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "#InterProScan-protein_formats.yaml/protein_formats"
                        }
                    ],
                    "default": "TSV",
                    "inputBinding": {
                        "position": 10,
                        "itemSeparator": ",",
                        "prefix": "--formats"
                    },
                    "label": "output format",
                    "doc": "Optional, case-insensitive, comma separated list of output formats. Supported formats are TSV, XML, JSON, GFF3, HTML and SVG. Default for protein sequences are TSV, XML and GFF3, or for nucleotide sequences GFF3 and XML."
                },
                {
                    "id": "#InterProScan-v5.cwl/i5/databases",
                    "type": "Directory"
                },
                {
                    "id": "#InterProScan-v5.cwl/i5/disableResidueAnnotation",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "--disable-residue-annot"
                    },
                    "label": "Disables residue annotation",
                    "doc": "Optional, excludes sites from the XML, JSON output."
                },
                {
                    "id": "#InterProScan-v5.cwl/i5/seqtype",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#InterProScan-v5.cwl/i5/seqtype/seqtype/p",
                                "#InterProScan-v5.cwl/i5/seqtype/seqtype/n"
                            ],
                            "name": "#InterProScan-v5.cwl/i5/seqtype/seqtype"
                        }
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "--seqtype"
                    },
                    "label": "Sequence type",
                    "doc": "Optional, the type of the input sequences (dna/rna (n) or protein (p)). The default sequence type is protein."
                }
            ],
            "doc": "InterProScan is the software package that allows sequences (protein and nucleic) to be scanned against InterPro's signatures. Signatures are predictive models, provided by several different databases, that make up the InterPro consortium.\n\nThis tool description is using a Docker container tagged as version v5.30-69.0.\n\nDocumentation on how to run InterProScan 5 can be found here: https://github.com/ebi-pf-team/interproscan/wiki/HowToRun",
            "label": "InterProScan: protein sequence classifier",
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "cp -r /opt/interproscan $(runtime.outdir)/interproscan;"
                },
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "cp -rs $(inputs.databases.path)/data/* $(runtime.outdir)/interproscan/data;"
                },
                {
                    "position": 2,
                    "shellQuote": false,
                    "valueFrom": "$(runtime.outdir)/interproscan/interproscan.sh"
                },
                {
                    "position": 3,
                    "valueFrom": "--disable-precalc"
                },
                {
                    "position": 4,
                    "valueFrom": "--goterms"
                },
                {
                    "position": 5,
                    "valueFrom": "--pathways"
                },
                {
                    "position": 6,
                    "prefix": "--tempdir",
                    "valueFrom": "$(runtime.tmpdir)"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "enum",
                            "name": "#InterProScan-apps.yaml/apps",
                            "symbols": [
                                "#InterProScan-apps.yaml/apps/TIGRFAM",
                                "#InterProScan-apps.yaml/apps/SFLD",
                                "#InterProScan-apps.yaml/apps/SUPERFAMILY",
                                "#InterProScan-apps.yaml/apps/Gene3D",
                                "#InterProScan-apps.yaml/apps/Hamap",
                                "#InterProScan-apps.yaml/apps/Coils",
                                "#InterProScan-apps.yaml/apps/ProSiteProfiles",
                                "#InterProScan-apps.yaml/apps/SMART",
                                "#InterProScan-apps.yaml/apps/CDD",
                                "#InterProScan-apps.yaml/apps/PRINTS",
                                "#InterProScan-apps.yaml/apps/PIRSF",
                                "#InterProScan-apps.yaml/apps/ProSitePatterns",
                                "#InterProScan-apps.yaml/apps/PfamA",
                                "#InterProScan-apps.yaml/apps/ProDom",
                                "#InterProScan-apps.yaml/apps/MobiDBLite",
                                "#InterProScan-apps.yaml/apps/SignalP_GRAM_POSITIVE",
                                "#InterProScan-apps.yaml/apps/SignalP_GRAM_NEGATIVE",
                                "#InterProScan-apps.yaml/apps/SignalP_EUK",
                                "#InterProScan-apps.yaml/apps/Phobius",
                                "#InterProScan-apps.yaml/apps/TMHMM"
                            ]
                        },
                        {
                            "type": "enum",
                            "name": "#InterProScan-protein_formats.yaml/protein_formats",
                            "symbols": [
                                "#InterProScan-protein_formats.yaml/protein_formats/TSV",
                                "#InterProScan-protein_formats.yaml/protein_formats/XML",
                                "#InterProScan-protein_formats.yaml/protein_formats/GFF3",
                                "#InterProScan-protein_formats.yaml/protein_formats/JSON",
                                "#InterProScan-protein_formats.yaml/protein_formats/HTML",
                                "#InterProScan-protein_formats.yaml/protein_formats/SVG"
                            ]
                        }
                    ]
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 2048,
                    "ramMax": 8192,
                    "coresMin": 4
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biocontainers/interproscan:v5.30-69.0_cv1"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "http://galaxyproject.org/cwl#interface",
                    "http://galaxyproject.org/cwl#inputs": [
                        {
                            "http://galaxyproject.org/cwl#name": "applications",
                            "http://galaxyproject.org/cwl#type": "text",
                            "http://galaxyproject.org/cwl#optional": true
                        },
                        {
                            "http://galaxyproject.org/cwl#name": "proteinFile",
                            "http://galaxyproject.org/cwl#type": "data",
                            "http://galaxyproject.org/cwl#format": "txt"
                        }
                    ]
                }
            ],
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/author": "Michael Crusoe, Aleksandra Ola Tarkowska, Maxim Scheremetjew",
            "outputs": [
                {
                    "id": "#InterProScan-v5.cwl/i5/i5Annotations",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.inputFile.nameroot).fasta.tsv"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "cat"
            ],
            "inputs": [
                {
                    "id": "#concatenate.cwl/files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "streamable": true
                },
                {
                    "id": "#concatenate.cwl/outputFileName",
                    "type": "string"
                }
            ],
            "outputs": [
                {
                    "id": "#concatenate.cwl/result",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outputFileName)",
                        "outputEval": "${ self[0].format = inputs.files[0].format;\n   return self; }\n"
                    }
                }
            ],
            "doc": "The cat (short for \u201cconcatenate\u201c) command is one of the most frequently used command in Linux/Unix like operating systems. cat command allows us to create single or multiple files, view contain of file, concatenate files and redirect output in terminal or files.\n",
            "label": "Redirecting Multiple Files Contain in a Single File",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 100,
                    "coresMax": 1
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "stdout": "$(inputs.outputFileName)",
            "id": "#concatenate.cwl",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/author": "Michael Crusoe, Maxim Scheremetjew"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "python3"
            ],
            "inputs": [
                {
                    "id": "#fasta_chunker.cwl/chunk_size",
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 10
                },
                {
                    "id": "#fasta_chunker.cwl/seqs",
                    "type": "File",
                    "format": "http://edamontology.org/format_1929"
                }
            ],
            "outputs": [
                {
                    "id": "#fasta_chunker.cwl/chunks",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "chunks/*_*.fasta"
                    },
                    "format": "http://edamontology.org/format_1929"
                }
            ],
            "doc": "based upon code by developers from EMBL-EBI",
            "label": "split FASTA by number of records",
            "arguments": [
                {
                    "position": 0,
                    "prefix": "-c",
                    "valueFrom": "from Bio import SeqIO\nimport os\ncurrentSequences = []\nos.mkdir(\"$(runtime.outdir)/chunks\")\nfor record in SeqIO.parse(\"$(inputs.seqs.path)\", \"fasta\"):\n    currentSequences.append(record)\n    if len(currentSequences) == $(inputs.chunk_size):\n        fileName = currentSequences[0].id + \"_\" + currentSequences[-1].id + \".fasta\"\n        for char in [ \"/\", \" \", \":\" ]:\n            fileName = fileName.replace(char, \"_\")\n        SeqIO.write(currentSequences, \"$(runtime.outdir)/chunks/\"+fileName, \"fasta\")\n        currentSequences = []\n\n# write any remaining sequences\nif len(currentSequences) > 0:\n    fileName = currentSequences[0].id + \"_\" + currentSequences[-1].id + \".fasta\"\n    for char in [ \"/\", \" \", \":\" ]:\n        fileName = fileName.replace(char, \"_\")\n    SeqIO.write(currentSequences, \"$(runtime.outdir)/chunks/\"+fileName, \"fasta\")\n"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 100,
                    "coresMax": 1
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biopython/biopython:latest"
                },
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_007173"
                            ],
                            "version": [
                                "1.65",
                                "1.66",
                                "1.69",
                                "1.72"
                            ],
                            "package": "biopython"
                        }
                    ]
                }
            ],
            "id": "#fasta_chunker.cwl",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/author": "Michael Crusoe, Maxim Scheremetjew"
        },
        {
            "class": "Workflow",
            "label": "Runs InterProScan on batches of sequences to retrieve functional annotations.",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "types": [
                        {
                            "$import": "#InterProScan-apps.yaml/apps"
                        },
                        {
                            "$import": "#InterProScan-protein_formats.yaml/protein_formats"
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "inputs": [
                {
                    "format": "http://edamontology.org/format_1929",
                    "id": "#main/inputFile",
                    "type": "File",
                    "label": "Input file path",
                    "doc": "Optional, path to fasta file that should be loaded on Master startup. Alternatively, in CONVERT mode, the InterProScan 5 XML file to convert."
                },
                {
                    "id": "#main/applications",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "#InterProScan-apps.yaml/apps"
                        }
                    ],
                    "label": "Analysis",
                    "doc": "Optional, comma separated list of analyses. If this option is not set, ALL analyses will be run."
                },
                {
                    "id": "#main/outputFormat",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "#InterProScan-protein_formats.yaml/protein_formats"
                        }
                    ],
                    "label": "output format",
                    "doc": "Optional, case-insensitive, comma separated list of output formats. Supported formats are TSV, XML, JSON, GFF3, HTML and SVG. Default for protein sequences are TSV, XML and GFF3, or for nucleotide sequences GFF3 and XML."
                },
                {
                    "id": "#main/databases",
                    "type": "Directory"
                },
                {
                    "id": "#main/chunk_size",
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 500
                },
                {
                    "id": "#main/disableResidueAnnotation",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Disables residue annotation",
                    "doc": "Optional, excludes sites from the XML, JSON output."
                },
                {
                    "id": "#main/seqtype",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#main/seqtype/seqtype/p",
                                "#main/seqtype/seqtype/n"
                            ],
                            "name": "#main/seqtype/seqtype"
                        }
                    ],
                    "label": "Sequence type",
                    "doc": "Optional, the type of the input sequences (dna/rna (n) or protein (p)). The default sequence type is protein."
                },
                {
                    "id": "#main/catOutputFileName",
                    "type": "string",
                    "default": "full_i5_annotations"
                }
            ],
            "outputs": [
                {
                    "id": "#main/i5Annotations",
                    "type": "File",
                    "outputSource": "#main/combine_interproscan_results/result"
                }
            ],
            "steps": [
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#main/run_interproscan/i5Annotations",
                            "id": "#main/combine_interproscan_results/files"
                        },
                        {
                            "source": "#main/catOutputFileName",
                            "id": "#main/combine_interproscan_results/outputFileName"
                        }
                    ],
                    "out": [
                        "#main/combine_interproscan_results/result"
                    ],
                    "id": "#main/combine_interproscan_results"
                },
                {
                    "label": "Run InterProScan on chunked sequence files",
                    "run": "#InterProScan-v5.cwl",
                    "in": [
                        {
                            "source": "#main/applications",
                            "id": "#main/run_interproscan/applications"
                        },
                        {
                            "source": "#main/databases",
                            "id": "#main/run_interproscan/databases"
                        },
                        {
                            "source": "#main/disableResidueAnnotation",
                            "id": "#main/run_interproscan/disableResidueAnnotation"
                        },
                        {
                            "source": "#main/split_seqs/chunks",
                            "id": "#main/run_interproscan/inputFile"
                        },
                        {
                            "source": "#main/outputFormat",
                            "id": "#main/run_interproscan/outputFormat"
                        }
                    ],
                    "scatter": "#main/run_interproscan/inputFile",
                    "out": [
                        "#main/run_interproscan/i5Annotations"
                    ],
                    "id": "#main/run_interproscan"
                },
                {
                    "run": "#fasta_chunker.cwl",
                    "in": [
                        {
                            "source": "#main/chunk_size",
                            "id": "#main/split_seqs/chunk_size"
                        },
                        {
                            "source": "#main/inputFile",
                            "id": "#main/split_seqs/seqs"
                        }
                    ],
                    "out": [
                        "#main/split_seqs/chunks"
                    ],
                    "id": "#main/split_seqs"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/author": "Maxim Scheremetjew"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/docs/schema_org_rdfa.html",
        "http://edamontology.org/EDAM_1.16.owl",
        "http://edamontology.org/EDAM_1.20.owl"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
